==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/activity/l10n/ar.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "نشاط",
    "Your settings have been updated." : "تم تحديث الإعدادات الخاصة بك.",
    "A file or folder has been <strong>shared</strong>" : "ملف أو مجلد تم </strong>مشاركته<strong> ",
    "A new file or folder has been <strong>created</strong>" : "تم <strong>  إنشاء</strong> ملف جديد أو مجلد ",
    "A file or folder has been <strong>changed</strong>" : "تم  <strong> تغيير</strong> ملف أو مجلد",
    "A file or folder has been <strong>deleted</strong>" : "تم <strong>حذف </strong> ملف أو مجلد",
    "A file or folder has been <strong>restored</strong>" : "تم <strong> استعادة </strong> ملف أو مجلد",
    "You created %1$s" : "لقد أنشأت %1$s",
    "%2$s created %1$s" : "%2$s أنشأ %1$s",
    "%1$s was created in a public folder" : "تم إنشاء %1$s في مجلد عام",
    "You changed %1$s" : "لقد غيرت %1$s",
    "%2$s changed %1$s" : "%2$s غير %1$s",
    "You deleted %1$s" : "حذفت %1$s",
    "%2$s deleted %1$s" : "%2$s حذف %1$s",
    "You restored %1$s" : "لقد قمت باستعادة %1$s",
    "%2$s restored %1$s" : "%2$s مستعاد %1$s",
    "You shared %1$s with %2$s" : "شاركت %1$s مع %2$s",
    "You shared %1$s with group %2$s" : "أنت شاركت %1$s مع مجموعة %2$s",
    "%2$s shared %1$s with you" : "%2$s شارك %1$s معك",
    "You shared %1$s via link" : "لقد قمت بمشاركة %1$s عبر الرابط",
    "Activity notification" : "تنبيه النشاط",
    "All Activities" : "جميع النشاطات",
    "Activities by you" : "نشاطاتك",
    "Activities by others" : "نشاطات الآخرين",
    "Shares" : "المشاركات",
    "Files" : "الملفات",
    "in %s" : "في %s",
    "%s and %s" : "%s و %s",
    "%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>::%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>" : ["","","","","",""],
    "%s and %n more::%s and %n more" : ["","","","","",""],
    "Hello %s," : "مرحبا%so ,",
    "You are receiving this email because in the last hour the following things happened at %s" : "لقد تلقيت هذا البريد الإلكتروني لحدوث الأمور التالية في  الساعة الأخيرة  %s",
    "You are receiving this email because in the last day the following things happened at %s" : "لقد تلقيت هذا البريد الإلكتروني  لحدوث الأمور التالية في اليوم الأخير %s",
    "You are receiving this email because in the last week the following things happened at %s" : "لقد تلقيت هذا البريد الإلكتروني لحدوث الأمور التالية في الأسبوع الأخير %s",
    "You will see a list of events here when you start to use your %s." : "سترى هنا قائمة بالأحداث عندما تقوم بالبدء في استخدام  %s الخاص بك. ",
    "No more events to load" : "لا توجد أي أحداث للتحميل",
    "Enable RSS feed" : "تمكين التزويد بمقتطفات الأخبار أر أس أس",
    "Notifications" : "الإشعارات",
    "Mail" : "البريد",
    "Stream" : "بث",
    "List your own actions in the stream" : "عدد أنشطتك",
    "Notify about your own actions via email" : "التنبيه عن أنشطتي عبر البريد الإلكتروني",
    "You need to set up your email address before you can receive notification emails." : "عليك إعداد عنوان البريد الإلكتروني الخاص بك قبل البدأ باستقبال رسائل إلكترونية تنبيهيه ",
    "Send emails:" : "إرسال رسائل إلكترونية ",
    "Hourly" : "مرة كل ساعة",
    "Daily" : "يومي",
    "Weekly" : "أسبوعي",
    "Activity feed" : "تغذية الأنشطة",
    "Personal activity feed for %s" : "تغذية الأنشطة الشخصية ل %s"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/activity/l10n/ar.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "نشاط",
    "Personal activity feed for %s" : "تغذية الأنشطة الشخصية ل %s",
    "Your feed URL is invalid" : "رابط التغدية الخاص بك غير شغال",
    "Your settings have been updated." : "تم تحديث الإعدادات الخاصة بك.",
    "There are no events for this filter" : "لا توجد هناك فعاليات وفق ما خصصته",
    "Activity notification" : "تنبيه النشاط",
    "All Activities" : "جميع النشاطات",
    "Activities by you" : "نشاطاتك",
    "Activities by others" : "نشاطات الآخرين",
    "\"remote user\"" : "\"عضوية التحكم\"",
    "in %s" : "في %s",
    "%s and %s" : "%s و %s",
    "Hello %s," : "مرحبا%so ,",
    "You are receiving this email because in the last hour the following things happened at %s" : "لقد تلقيت هذا البريد الإلكتروني لحدوث الأمور التالية في  الساعة الأخيرة  %s",
    "You are receiving this email because in the last day the following things happened at %s" : "لقد تلقيت هذا البريد الإلكتروني  لحدوث الأمور التالية في اليوم الأخير %s",
    "You are receiving this email because in the last week the following things happened at %s" : "لقد تلقيت هذا البريد الإلكتروني لحدوث الأمور التالية في الأسبوع الأخير %s",
    "Notifications" : "الإشعارات",
    "Mail" : "البريد",
    "Stream" : "بث",
    "List your own actions in the stream" : "عدد أنشطتك",
    "Notify about your own actions via email" : "التنبيه عن أنشطتي عبر البريد الإلكتروني",
    "You need to set up your email address before you can receive notification emails." : "عليك إعداد عنوان البريد الإلكتروني الخاص بك قبل البدأ باستقبال رسائل إلكترونية تنبيهيه ",
    "Send emails:" : "إرسال رسائل إلكترونية ",
    "Hourly" : "مرة كل ساعة",
    "Daily" : "يومي",
    "Weekly" : "أسبوعي",
    "Activity feed" : "تغذية الأنشطة",
    "Enable RSS feed" : "تمكين التزويد بمقتطفات الأخبار أر أس أس",
    "No more events to load" : "لا توجد أي أحداث للتحميل",
    "Files" : "الملفات"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
